import { Component } from '@clutchd/component';
import { IFlexProps } from '@clutchd/flex';
import * as React from 'react';
import { WithMinWidth, WithMinHeight } from '@clutchd/tailwind';

/**
 * Type to define `Footer` element.
 */
type IFooter = React.ElementRef<typeof Component.footer>;
/**
 * Type to define `Footer` props.
 */
interface IFooterProps extends IFlexProps {
}
/**
 * Type to define `Footer` props with html attributes.
 */
interface IFooterHtmlProps extends IFooterProps, React.ComponentPropsWithoutRef<typeof Component.footer> {
}
/**
 * `Footer` - A layout component designed to contain a page's footer content. Renders as a `footer` element.
 * @param props `IFooterHtmlProps` used to render this `Footer`.
 * @returns `Footer` component.
 */
declare const Footer: React.ForwardRefExoticComponent<IFooterHtmlProps & React.RefAttributes<HTMLElement>>;

/**
 * Type to define `Header` element.
 */
type IHeader = React.ElementRef<typeof Component.header>;
/**
 * Type to define `Header` props.
 */
interface IHeaderProps extends IFlexProps {
}
/**
 * Type to define `Header` props with html attributes.
 */
interface IHeaderHtmlProps extends IHeaderProps, React.ComponentPropsWithoutRef<typeof Component.header> {
}
/**
 * `Header` - A layout component designed to contain a page's header content. Renders as a `header` element.
 * @param props `IHeaderHtmlProps` used to render this `Header`.
 * @returns `Header` component.
 */
declare const Header: React.ForwardRefExoticComponent<IHeaderHtmlProps & React.RefAttributes<HTMLElement>>;

/**
 * Type to define `Main` element.
 */
type IMain = React.ElementRef<typeof Component.main>;
/**
 * Type to define `Main` props.
 */
interface IMainProps extends IFlexProps {
}
/**
 * Type to define `Main` props with html attributes.
 */
interface IMainHtmlProps extends IMainProps, React.ComponentPropsWithoutRef<typeof Component.main> {
}
/**
 * `Main` - A layout component designed to contain a page's primary Main. Renders as a `main` element.
 * @param props `IMainHtmlProps` used to render this `Main`.
 * @returns `Main` component.
 */
declare const Main: React.ForwardRefExoticComponent<IMainHtmlProps & React.RefAttributes<HTMLElement>>;

/**
 * Type to define `Page` element.
 */
type IPage = React.ElementRef<typeof Component.div>;
/**
 * Type to define `Page` props.
 */
interface IPageProps extends IFlexProps, WithMinWidth, WithMinHeight {
}
/**
 * Type to define `Page` props with html attributes.
 */
interface IPageHtmlProps extends IPageProps, React.ComponentPropsWithoutRef<typeof Component.div> {
}
/**
 * `Page` - A `Container` designed to contain an entire page. Renders as a `div` element that fills the screen.
 * @param props `IPageHtmlProps` used to render this `Page`.
 * @returns `Page` component.
 */
declare const Page: React.ForwardRefExoticComponent<IPageHtmlProps & React.RefAttributes<HTMLDivElement>>;

export { Footer, Header, type IFooter, type IFooterHtmlProps, type IFooterProps, type IHeader, type IHeaderHtmlProps, type IHeaderProps, type IMain, type IMainHtmlProps, type IMainProps, type IPage, type IPageHtmlProps, type IPageProps, Main, Page };
